@@ -53,11 +53,7 @@ class method:
     def __get__(self, instance, type=None, /):
         if instance is None:
             return self
-        try:
-            return self.__method__
-        except AttributeError:
-            method = self.__method__ = MethodType(self.__func__, instance)
-            return method
+        return MethodType(self.__func__, instance)
 
     def __set__(self, instance, value, /):
         raise TypeError("can't set value")
